@@ -61,6 +61,21 @@ augment_ode <- function(bnc_dag, ...) {
                  MoreArgs = list(x = bnc_dag), SIMPLIFY = FALSE)
   stopifnot(all(vapply(dags, is_ode, FUN.VALUE = logical(1))))
   dags
+} 
+#' Arcs that do not invalidate the k-DB structure
+#' 
+#' @param ... Ignored.
+#' @keywords internal
+augment_kdb <- function(kdbk) {
+  stopifnot(is.numeric(kdbk), kdbk > 0)
+  function(bnc_dag, ...) {
+    arcs <- augment_kdb_arcs(bnc_dag, k = kdbk)
+    if (length(arcs) == 0) return(NULL)
+    dags <- mapply(add_feature_parents, arcs[, 'from'], arcs[, 'to'], 
+                   MoreArgs = list(x = bnc_dag), SIMPLIFY = FALSE)
+    stopifnot(all(vapply(dags, is_kde, kdbk, FUN.VALUE = logical(1))))
+    dags
+  }
 }
 #' Returns augmenting arcs that do not invalidate the ODE. 
 #' 
@@ -75,8 +90,31 @@ augment_ode_arcs <- function(bnc_dag) {
   non_orphans <- setdiff(features(bnc_dag), orphans)
   arcs <- arcs_to_orphans(orphans, non_orphans)
   arcs <- discard_cycles(arcs, bnc_dag)
-  # discard equivalent arcs
+  # reversed arcs are equivalent in odes, since no v-structs, thus prune them 
+  # TODO: move these discard functions to graph-edgematrix-utils or something
+  # b <- discard_reversed(arcs)
+  # d <- discard_reversed2(arcs)
+  # stopifnot(identical(dim(b), dim(d)))
   discard_reversed(arcs)
+  # d <- discard_reversed2(arcs)
+  # discard_reversed2(arcs)
+} 
+#' Returns augmenting arcs that do not invalidate the k-DB. 
+#' 
+#' @keywords internal
+#' @return a character matrix. NULL if no arcs can be added.
+augment_kdb_arcs <- function(bnc_dag, k) {
+  stopifnot(is_kde(bnc_dag, k = k)) 
+  orphans <- upto_k_parents(bnc_dag, k) 
+  # An kDE must have at least one with < k parents
+  stopifnot(length(orphans) >= k)  
+  # There are k that do have less than k parents 
+  # if (length(orphans) <= k) return(matrix(character(), ncol = 2))
+  non_orphans <- setdiff(features(bnc_dag), orphans)
+  arcs <- arcs_to_orphans(orphans, non_orphans) 
+  arcs <- discard_existing(arcs, bnc_dag)
+  arcs <- discard_cycles(arcs, bnc_dag)
+  arcs 
 }
 # Returns each possible ode-augmenting arc. It also includes equivalent arcs among orphans --- e.g., A -> B is yields an equivalent structure as B -> A --- but this is handled by discard_reversed. Returns a data frame.
 arcs_to_orphans <- function(orphans, non_orphans) {
@@ -97,7 +135,19 @@ arcs_to_orphans <- function(orphans, non_orphans) {
     a <- rbind(a, b)  
   }
   as.matrix(a)
-}
+}  
+# Remove from arcs_df those already in bnc_dag
+discard_existing <- function(arcs_df, bnc_dag) { 
+  stopifnot(is.matrix(arcs_df), is.character(arcs_df))
+  in_bnc_dag <- dag(bnc_dag)$edges
+  # They are not sorted. For each of a I want to see if it is already in b.  
+  # It is OK if the first ones match. if so, then I will look at the second. 
+  list_from <- lapply(arcs_df[, 'from'], '==', in_bnc_dag[, 'from'] )
+  list_to   <- lapply(arcs_df[, 'to'], '==', in_bnc_dag[, 'to'] )
+  both <- mapply('&', list_from, list_to, SIMPLIFY = FALSE)
+  both <- vapply(both, any, FUN.VALUE = logical(1))  
+  arcs_df[!both, , drop = FALSE]
+} 
 # Remove from arcs_df arcs that would introduce a cycle in bnc_dag
 discard_cycles <- function(arcs_df, bnc_dag) {
   stopifnot(is.matrix(arcs_df), is.character(arcs_df))
@@ -114,24 +164,10 @@ discard_cycles <- function(arcs_df, bnc_dag) {
 }
 discard_reversed <- function(matrix) {
   if (nrow(matrix) == 0) return(matrix(character(), ncol = 2))
-  # Remove name so that reversed is the exact reflection
-  remember_names <- colnames(matrix)
-  matrix <- unname(matrix)
-  reversed <- matrix[, rev(seq_len(ncol(matrix)))]
-  stopifnot(identical(matrix, reversed[, 2:1]))
-  unique <- rep(FALSE, nrow(matrix))
-  # Count last element as unique
-  unique[length(unique)] <- TRUE
-  for (row in rev(seq_len(nrow(matrix) - 1))) {
-    this_row <- matrix[row, ]
-    unique[row] <- !any(apply(reversed[unique, , drop = FALSE], 1, 
-                              identical, this_row))
-  }
+  unique <- find_non_reversed(matrix)
   matrix <- matrix[ unique, , drop = FALSE]
-  colnames(matrix) <- remember_names
   matrix
-}
-
+} 
 augment_ode_sp <- function(bnc_dag, features_to_include, train, test) {
   rm(features_to_include) # ignored
   # Select superparent:
