@@ -3,7 +3,7 @@ context("Learn struct")
 test_that("nb  Nominal", {
   n <- nb('class', car)
   expect_identical('class', class_var(n))
-  expect_equal(graph::numEdges(as_graphNEL(n)), 6) 
+  expect_equal(graph_num_arcs(dag(n)), 6) 
 })
 
 test_that("nb   Class not in dataset", {
@@ -12,7 +12,7 @@ test_that("nb   Class not in dataset", {
 
 test_that("nb No features ", {
   n <- nb('class', car[, 7, drop = FALSE])
-  expect_equal(graph::numEdges(as_graphNEL(n)), 0)
+  expect_equal(graph_num_arcs(dag(n)), 0)
   # Not numeric dataset
 })
 
@@ -56,4 +56,18 @@ test_that("tanhc sp nominal", {
   t <- tan_hcsp('class', dataset = car, k = 10, epsilon = 0)
   expect_equal(length(features(t)), 6)
   expect_equal(narcs(t), 11)
-})
\ No newline at end of file
+  nfams <- sapply(families(t), length)
+  expect_true(max(nfams) < 5) 
+}) 
+
+test_that("kdb nominal", {
+  skip_on_cran()
+  set.seed(0)
+  t <- kdb('class', dataset = car, kdb = 1, k = 10, epsilon = 0)
+  set.seed(0)
+  to <- tan_hc('class', dataset = car, k = 10, epsilon = 0)
+  expect_false(isTRUE(all.equal(t, to)))
+  t$.call_struct <- NULL
+  to$.call_struct <- NULL
+  expect_true(isTRUE(all.equal(t, to)))
+})  
\ No newline at end of file
